@@ -6,7 +6,7 @@ use MooX::Options prefer_commandline => 1;
 use IO::All;
 use Bioinfo::PBS::Queue;
 
-our $VERSION = '0.1.1'; # VERSION: 
+our $VERSION = '0.1.2'; # VERSION: 
 # ABSTRACT: my perl module and CLIs for Biology
 
 
@@ -30,7 +30,7 @@ option num => (
 
 option db => (
   is  => 'rw',
-  fomrat => 's',
+  format => 's',
   short => 'd',
   default => sub { 'nr_plant' },
   doc => 'the database that blast will use',
@@ -77,7 +77,7 @@ option prefix => (
   is => 'ro',
   format => 's',
   short => 'p',
-  default => sub { 'prefix' },
+  default => sub { '' },
   doc => 'the prefix of the split file',
 );
 
@@ -146,14 +146,14 @@ sub submit_pbs {
     }
   )->all_files;
 
-  my $queue_name = $input->filename;
+  my $queue_name = io($input)->filename;
   $queue_name =~s/\.fa|\.pep|\.fasta//;
   say "PBS Queue name: $queue_name";
   chdir "$outdir";
   my $pbs = Bioinfo::PBS::Queue->new(name => $queue_name);
   for my $fa (@io_fas) {
-    my $cmd = "blastp -query $fa -out $fa.blast -db $db -outfmt 5 -evalue 1e-5 -num_threads $cpu -max_target_seqs 10";
     my $fa_name = $fa->filename;
+    my $cmd = "blastp -query $fa_name -out $fa_name.blast -db $db -outfmt 5 -evalue 1e-5 -num_threads $cpu -max_target_seqs 10";
     $fa_name =~s/\.fa|\.pep|\.fasta//;
     my $para = {
       cpu => $cpu,
@@ -175,7 +175,7 @@ sub local_blast {
     }
   )->all_files;
 
-  my $in_name = $input->filename;
+  my $in_name = io($input)->filename;
   $in_name =~s/\.fa|\.fasta|\.pep//;
   chdir "$outdir";
   use Parallel::ForkManager;
@@ -183,13 +183,14 @@ sub local_blast {
   LOOP_DATA:
   for my $fa (@io_fas) {
     my $pid = $pm->start and next LOOP_DATA;
-    my $cmd = "blastp -query $fa -out $fa.blast -db $db -outfmt 5 -evalue 1e-5 -num_threads $cpu -max_target_seqs 10";
+    my $fa_name = $fa->filename;
+    my $cmd = "blastp -query $fa_name -out $fa.xml -db $db -outfmt 5 -evalue 1e-5 -num_threads $cpu -max_target_seqs 10";
     system($cmd);
     $pm->finish;
   }
   $pm->wait_all_chilren;
-  system("cat *.blast >$in_name.blast");
-  say "finished all"
+  system("cat *.blast >$in_name.xml");
+  say "finished all";
 }
 
 1;
@@ -206,7 +207,7 @@ Bioinfo::App::Cmd::Fasta::Cmd::SplitBlast - my perl module and CLIs for Biology
 
 =head1 VERSION
 
-version 0.1.1
+version 0.1.2
 
 =head1 SYNOPSIS
 
