@@ -6,7 +6,7 @@ use IO::All;
 use List::Util 'uniq';
 use namespace::autoclean;
 
-our $VERSION = '0.1.1'; # VERSION:
+our $VERSION = '0.1.2'; # VERSION:
 # ABSTRACT: used to submit a batch of task to Torque cluster
 
 
@@ -45,6 +45,12 @@ has name => (
   default => sub { 'pbs' },
 );
 
+has task_running_num => (
+  is  => 'rw',
+  isa => 'Int',
+  default => sub { '1' }
+);
+
 has _log => (
   is  => 'rw',
   isa => 'IO::All',
@@ -88,13 +94,15 @@ has stage => (
 
 sub execute {
   my $self = shift;
+  my $task_run_num = $self->task_running_num;
   my @tasks =  $self->all_tasks;
   my @stages = uniq (map { $_->priority } @tasks);
   for my $stage (@stages) {
     $self->_log->lock->append("# Stage$stage: running\n")->unlock;
     say "Stage $stage";
     my @stage_tasks = $self->filter_tasks( sub {$_->priority == $stage} );
-    my $pm = Parallel::ForkManager->new($#stage_tasks+1);
+    my $paralell_num = $task_run_num || ($#stage_tasks + 1);
+    my $pm = Parallel::ForkManager->new($paralell_num);
     DATA_LOOP:
     for my $task (@stage_tasks) {
       sleep 1;
@@ -136,7 +144,7 @@ Bioinfo::PBS::Queue - used to submit a batch of task to Torque cluster
 
 =head1 VERSION
 
-version 0.1.1
+version 0.1.2
 
 =head1 SYNOPSIS
 
